Boost logo

Boost-Commit :

Subject: [Boost-commit] svn:boost r69917 - in trunk/libs/geometry: doc/doxy/doxygen_input/groups doc/doxy/doxygen_input/pages doc/doxy/doxygen_input/sourcecode doc/src/examples/algorithms example example/extensions/gis/projections example/with_external_libs test/algorithms
From: barend.gehrels_at_[hidden]
Date: 2011-03-13 07:10:32


Author: barendgehrels
Date: 2011-03-13 07:10:27 EDT (Sun, 13 Mar 2011)
New Revision: 69917
URL: http://svn.boost.org/trac/boost/changeset/69917

Log:
Renamed combine to expand, part 2: test, doc and examples
Added:
   trunk/libs/geometry/test/algorithms/expand.cpp
      - copied, changed from r69910, /trunk/libs/geometry/test/algorithms/combine.cpp
   trunk/libs/geometry/test/algorithms/expand.vcproj
      - copied, changed from r69910, /trunk/libs/geometry/test/algorithms/combine.vcproj
   trunk/libs/geometry/test/algorithms/test_expand.hpp
      - copied, changed from r69910, /trunk/libs/geometry/test/algorithms/test_combine.hpp
Removed:
   trunk/libs/geometry/test/algorithms/combine.cpp
   trunk/libs/geometry/test/algorithms/combine.vcproj
   trunk/libs/geometry/test/algorithms/test_combine.hpp
Text files modified:
   trunk/libs/geometry/doc/doxy/doxygen_input/groups/groups.hpp | 2
   trunk/libs/geometry/doc/doxy/doxygen_input/pages/doxygen_pages.hpp | 2
   trunk/libs/geometry/doc/doxy/doxygen_input/sourcecode/doxygen_4.cpp | 2
   trunk/libs/geometry/doc/src/examples/algorithms/assign_inverse.cpp | 6 +-
   trunk/libs/geometry/doc/src/examples/algorithms/make_inverse.cpp | 6 +-
   trunk/libs/geometry/example/07_a_graph_route_example.cpp | 2
   trunk/libs/geometry/example/07_b_graph_route_example.cpp | 2
   trunk/libs/geometry/example/extensions/gis/projections/p03_projmap_example.cpp | 2
   trunk/libs/geometry/example/with_external_libs/qt.vsprops | 2
   trunk/libs/geometry/example/with_external_libs/x04_wxwidgets_world_mapper.cpp | 2
   trunk/libs/geometry/example/with_external_libs/x06_qt_world_mapper.cpp | 2
   trunk/libs/geometry/test/algorithms/Jamfile.v2 | 2
   trunk/libs/geometry/test/algorithms/algorithms_tests.sln | 2
   trunk/libs/geometry/test/algorithms/expand.cpp | 68 ++++++++++++++++++++--------------------
   trunk/libs/geometry/test/algorithms/expand.vcproj | 10 ++--
   trunk/libs/geometry/test/algorithms/test_expand.hpp | 14 ++++----
   16 files changed, 63 insertions(+), 63 deletions(-)

Modified: trunk/libs/geometry/doc/doxy/doxygen_input/groups/groups.hpp
==============================================================================
--- trunk/libs/geometry/doc/doxy/doxygen_input/groups/groups.hpp (original)
+++ trunk/libs/geometry/doc/doxy/doxygen_input/groups/groups.hpp 2011-03-13 07:10:27 EDT (Sun, 13 Mar 2011)
@@ -16,7 +16,6 @@
 \defgroup buffer buffer: calculate buffer of a geometry
 \defgroup centroid centroid: calculate centroid (center of gravity) of a geometry
 \defgroup clear clear: clear geometries
-\defgroup combine combine: add a geometry to a bounding box
 \defgroup compare compare: define compare functors for points
 \defgroup concepts geometry concepts: defines and checks concepts for geometries
 \defgroup convert convert: convert geometries from one type to another
@@ -30,6 +29,7 @@
 \defgroup enum enum: enumerations
 \defgroup envelope envelope: calculate envelope (minimum bounding rectangle) of a geometry
 \defgroup equals equals: detect if two geometries are spatially equal
+\defgroup expand expand: add a geometry to a bounding box
 \defgroup exterior_ring exterior_ring: exterior_ring
 \defgroup for_each for_each: apply a functor to each point or segment of a geometry
 \defgroup geometries geometries: geometries provided by default

Modified: trunk/libs/geometry/doc/doxy/doxygen_input/pages/doxygen_pages.hpp
==============================================================================
--- trunk/libs/geometry/doc/doxy/doxygen_input/pages/doxygen_pages.hpp (original)
+++ trunk/libs/geometry/doc/doxy/doxygen_input/pages/doxygen_pages.hpp 2011-03-13 07:10:27 EDT (Sun, 13 Mar 2011)
@@ -359,7 +359,7 @@
 - all algorithms accepting linestrings are now modified to get the linestring itself. In the previous version
   .begin(), end() had to be specified, This is not necessary anymore, because the Boost Range Library is used
   internally, and tag dispatching is used to distinguish different geometries
-- the "grow" utility is now splitted into buffer (growing a box with a value was in fact a buffer) and a combine.
+- the "grow" utility is now splitted into buffer (growing a box with a value was in fact a buffer) and a expand.
 - there was a generic "get" function with a const ref and a non const ref. This is splitted into "get" and "set"
 - there might be more changes, please contact if anything is unclear
 

Modified: trunk/libs/geometry/doc/doxy/doxygen_input/sourcecode/doxygen_4.cpp
==============================================================================
--- trunk/libs/geometry/doc/doxy/doxygen_input/sourcecode/doxygen_4.cpp (original)
+++ trunk/libs/geometry/doc/doxy/doxygen_input/sourcecode/doxygen_4.cpp 2011-03-13 07:10:27 EDT (Sun, 13 Mar 2011)
@@ -70,7 +70,7 @@
                 Tuple tuple(geometry, name);
 
                 tuples.push_back(tuple);
- boost::geometry::combine(box, boost::geometry::make_envelope<Box>(geometry));
+ boost::geometry::expand(box, boost::geometry::make_envelope<Box>(geometry));
             }
         }
     }

Modified: trunk/libs/geometry/doc/src/examples/algorithms/assign_inverse.cpp
==============================================================================
--- trunk/libs/geometry/example/07_a_graph_route_example.cpp (original)
+++ trunk/libs/geometry/example/07_a_graph_route_example.cpp 2011-03-13 07:10:27 EDT (Sun, 13 Mar 2011)
@@ -70,7 +70,7 @@
                 Tuple tuple(geometry, name);
 
                 tuples.push_back(tuple);
- boost::geometry::combine(box, boost::geometry::make_envelope<Box>(geometry));
+ boost::geometry::expand(box, boost::geometry::make_envelope<Box>(geometry));
             }
         }
     }

Modified: trunk/libs/geometry/example/07_b_graph_route_example.cpp
==============================================================================
--- trunk/libs/geometry/example/07_b_graph_route_example.cpp (original)
+++ trunk/libs/geometry/example/07_b_graph_route_example.cpp 2011-03-13 07:10:27 EDT (Sun, 13 Mar 2011)
@@ -74,7 +74,7 @@
                 Tuple tuple(geometry, name);
 
                 tuples.push_back(tuple);
- boost::geometry::combine(box, boost::geometry::make_envelope<Box>(geometry));
+ boost::geometry::expand(box, boost::geometry::make_envelope<Box>(geometry));
             }
         }
     }

Modified: trunk/libs/geometry/example/extensions/gis/projections/p03_projmap_example.cpp
==============================================================================
--- trunk/libs/geometry/example/extensions/gis/projections/p03_projmap_example.cpp (original)
+++ trunk/libs/geometry/example/extensions/gis/projections/p03_projmap_example.cpp 2011-03-13 07:10:27 EDT (Sun, 13 Mar 2011)
@@ -79,7 +79,7 @@
         if (transform(*it, xy_polygon, projection))
         {
             // Update bbox with box of this projected polygon
- combine(bbox, make_envelope<model::box<point_xy> >(xy_polygon));
+ expand(bbox, make_envelope<model::box<point_xy> >(xy_polygon));
 
             // Add projected polygon
             xy_polygons.push_back(xy_polygon);

Modified: trunk/libs/geometry/example/with_external_libs/qt.vsprops
==============================================================================
--- trunk/libs/geometry/example/with_external_libs/qt.vsprops (original)
+++ trunk/libs/geometry/example/with_external_libs/qt.vsprops 2011-03-13 07:10:27 EDT (Sun, 13 Mar 2011)
@@ -17,6 +17,6 @@
         />
         <UserMacro
                 Name="QT"
- Value="c:\software\libraries\Qt\4.6.2"
+ Value="c:\software\libraries\Qt\4.7.1"
         />
 </VisualStudioPropertySheet>

Modified: trunk/libs/geometry/example/with_external_libs/x04_wxwidgets_world_mapper.cpp
==============================================================================
--- trunk/libs/geometry/example/with_external_libs/x04_wxwidgets_world_mapper.cpp (original)
+++ trunk/libs/geometry/example/with_external_libs/x04_wxwidgets_world_mapper.cpp 2011-03-13 07:10:27 EDT (Sun, 13 Mar 2011)
@@ -123,7 +123,7 @@
                 Geometry geometry;
                 boost::geometry::read_wkt(line, geometry);
                 geometries.push_back(geometry);
- boost::geometry::combine(box, boost::geometry::make_envelope<Box>(geometry));
+ boost::geometry::expand(box, boost::geometry::make_envelope<Box>(geometry));
             }
         }
     }

Modified: trunk/libs/geometry/example/with_external_libs/x06_qt_world_mapper.cpp
==============================================================================
--- trunk/libs/geometry/example/with_external_libs/x06_qt_world_mapper.cpp (original)
+++ trunk/libs/geometry/example/with_external_libs/x06_qt_world_mapper.cpp 2011-03-13 07:10:27 EDT (Sun, 13 Mar 2011)
@@ -136,7 +136,7 @@
                 Geometry geometry;
                 boost::geometry::read_wkt(line, geometry);
                 geometries.push_back(geometry);
- boost::geometry::combine(box, boost::geometry::make_envelope<Box>(geometry));
+ boost::geometry::expand(box, boost::geometry::make_envelope<Box>(geometry));
             }
         }
     }

Modified: trunk/libs/geometry/test/algorithms/Jamfile.v2
==============================================================================
--- trunk/libs/geometry/test/algorithms/Jamfile.v2 (original)
+++ trunk/libs/geometry/test/algorithms/Jamfile.v2 2011-03-13 07:10:27 EDT (Sun, 13 Mar 2011)
@@ -13,7 +13,6 @@
     [ run assign.cpp ]
     [ run buffer.cpp ]
     [ run centroid.cpp ]
- [ run combine.cpp ]
     [ run comparable_distance.cpp ]
     [ run convert.cpp ]
     [ run convex_hull.cpp ]
@@ -23,6 +22,7 @@
     [ run distance.cpp ]
     [ run envelope.cpp ]
     [ run equals.cpp ]
+ [ run expand.cpp ]
     [ run for_each.cpp ]
     [ run intersection.cpp ]
     [ run intersects.cpp ]

Modified: trunk/libs/geometry/test/algorithms/algorithms_tests.sln
==============================================================================
--- trunk/libs/geometry/test/algorithms/algorithms_tests.sln (original)
+++ trunk/libs/geometry/test/algorithms/algorithms_tests.sln 2011-03-13 07:10:27 EDT (Sun, 13 Mar 2011)
@@ -6,7 +6,7 @@
 EndProject
 Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "assign", "assign.vcproj", "{94BC6547-67C1-44DB-903D-526537A91E23}"
 EndProject
-Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "combine", "combine.vcproj", "{5330DAB1-DF27-44FC-971B-3C5094F82FA3}"
+Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "expand", "expand.vcproj", "{5330DAB1-DF27-44FC-971B-3C5094F82FA3}"
 EndProject
 Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "convert", "convert.vcproj", "{FABF1AA7-F695-49F8-92F6-AB6C4B0C088A}"
 EndProject

Deleted: trunk/libs/geometry/test/algorithms/combine.cpp
==============================================================================
--- trunk/libs/geometry/test/algorithms/combine.cpp 2011-03-13 07:10:27 EDT (Sun, 13 Mar 2011)
+++ (empty file)
@@ -1,144 +0,0 @@
-// Boost.Geometry (aka GGL, Generic Geometry Library) test file
-//
-// Copyright Barend Gehrels 2007-2009, Geodan, Amsterdam, the Netherlands
-// Copyright Bruno Lalande 2008, 2009
-// Use, modification and distribution is subject to the Boost Software License,
-// Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at
-// http://www.boost.org/LICENSE_1_0.txt)
-
-#include <algorithms/test_combine.hpp>
-
-
-#include <boost/geometry/algorithms/make.hpp>
-
-#include <boost/geometry/geometries/geometries.hpp>
-#include <boost/geometry/geometries/adapted/c_array_cartesian.hpp>
-#include <boost/geometry/geometries/adapted/tuple_cartesian.hpp>
-#include <boost/geometry/geometries/adapted/std_pair_as_segment.hpp>
-#include <test_common/test_point.hpp>
-
-
-template <typename Point>
-void test_point_3d()
-{
- bg::model::box<Point> b = bg::make_inverse<bg::model::box<Point> >();
-
- test_combine<Point>(b, "POINT(1 2 5)", "(1,2,5),(1,2,5)");
- test_combine<Point>(b, "POINT(3 4 6)", "(1,2,5),(3,4,6)");
-
- test_combine<Point>(b, "POINT(4 4 5)", "(1,2,5),(4,4,6)");
- test_combine<Point>(b, "POINT(4 5 5)", "(1,2,5),(4,5,6)");
- test_combine<Point>(b, "POINT(10 10 4)", "(1,2,4),(10,10,6)");
- test_combine<Point>(b, "POINT(9 9 4)", "(1,2,4),(10,10,6)");
-
- test_combine<Point>(b, "POINT(0 2 7)", "(0,2,4),(10,10,7)");
- test_combine<Point>(b, "POINT(0 0 7)", "(0,0,4),(10,10,7)");
- test_combine<Point>(b, "POINT(-1 -1 5)", "(-1,-1,4),(10,10,7)");
- test_combine<Point>(b, "POINT(0 0 5)", "(-1,-1,4),(10,10,7)");
-
- test_combine<Point>(b, "POINT(15 -1 0)", "(-1,-1,0),(15,10,7)");
- test_combine<Point>(b, "POINT(-1 15 10)", "(-1,-1,0),(15,15,10)");
-}
-
-template <typename Point>
-void test_box_3d()
-{
- typedef bg::model::box<Point> box_type;
- box_type b = bg::make_inverse<box_type>();
-
- test_combine<box_type>(b, "BOX(0 2 5,4 4 6)", "(0,2,5),(4,4,6)");
- test_combine<box_type>(b, "BOX(0 1 5,4 6 6)", "(0,1,5),(4,6,6)");
- test_combine<box_type>(b, "BOX(-1 -1 6,10 10 5)", "(-1,-1,5),(10,10,6)");
- test_combine<box_type>(b, "BOX(3 3 6,3 3 5)", "(-1,-1,5),(10,10,6)");
-
- test_combine<box_type>(b, "BOX(3 15 7,-1 3 4)", "(-1,-1,4),(10,15,7)");
- test_combine<box_type>(b, "BOX(-15 3 7,3 20 4)", "(-15,-1,4),(10,20,7)");
- test_combine<box_type>(b, "BOX(3 -20 8,3 20 3)", "(-15,-20,3),(10,20,8)");
- test_combine<box_type>(b, "BOX(-20 3 8,20 3 3)", "(-20,-20,3),(20,20,8)");
-}
-
-
-
-template <typename P>
-void test_3d()
-{
- test_point_3d<P>();
- test_box_3d<P>();
-}
-
-template <typename Point>
-void test_2d()
-{
- typedef bg::model::box<Point> box_type;
- typedef std::pair<Point, Point> segment_type;
-
- box_type b = bg::make_inverse<box_type>();
-
- test_combine<box_type>(b, "BOX(1 1,2 2)", "(1,1),(2,2)");
-
- // Test an 'incorrect' box -> should also correctly update the bbox
- test_combine<box_type>(b, "BOX(3 4,0 1)", "(0,1),(3,4)");
-
- // Test a segment
- test_combine<segment_type>(b, "SEGMENT(5 6,7 8)", "(0,1),(7,8)");
-}
-
-template <typename Point>
-void test_spherical_degree()
-{
- bg::model::box<Point> b = bg::make_inverse<bg::model::box<Point> >();
-
- test_combine<Point>(b, "POINT(179.73 71.56)",
- "(179.73,71.56),(179.73,71.56)");
- test_combine<Point>(b, "POINT(177.47 71.23)",
- "(177.47,71.23),(179.73,71.56)");
-
- // It detects that this point is lying RIGHT of the others,
- // and then it "combines" it.
- // It might be argued that "181.22" is displayed instead. However, they are
- // the same.
- test_combine<Point>(b, "POINT(-178.78 70.78)",
- "(177.47,70.78),(-178.78,71.56)");
-}
-
-
-template <typename Point>
-void test_spherical_radian()
-{
- bg::model::box<Point> b = bg::make_inverse<bg::model::box<Point> >();
-
- test_combine<Point>(b, "POINT(3.128 1.249)",
- "(3.128,1.249),(3.128,1.249)");
- test_combine<Point>(b, "POINT(3.097 1.243)",
- "(3.097,1.243),(3.128,1.249)");
-
- // It detects that this point is lying RIGHT of the others,
- // and then it "combines" it.
- // It might be argued that "181.22" is displayed instead. However, they are
- // the same.
- test_combine<Point>(b, "POINT(-3.121 1.235)",
- "(3.097,1.235),(-3.121,1.249)");
-}
-
-int test_main(int, char* [])
-{
- test_2d<bg::model::point<int, 2, bg::cs::cartesian> >();
-
-
- test_3d<test::test_point>();
- test_3d<bg::model::point<int, 3, bg::cs::cartesian> >();
- test_3d<bg::model::point<float, 3, bg::cs::cartesian> >();
- test_3d<bg::model::point<double, 3, bg::cs::cartesian> >();
-
- test_spherical_degree<bg::model::point<double, 2, bg::cs::spherical<bg::degree> > >();
- test_spherical_radian<bg::model::point<double, 2, bg::cs::spherical<bg::radian> > >();
-
-
-#if defined(HAVE_TTMATH)
- test_3d<bg::model::point<ttmath_big, 3, bg::cs::cartesian> >();
- test_spherical_degree<bg::model::point<ttmath_big, 2, bg::cs::spherical<bg::degree> > >();
- test_spherical_radian<bg::model::point<ttmath_big, 2, bg::cs::spherical<bg::radian> > >();
-#endif
-
- return 0;
-}

Deleted: trunk/libs/geometry/test/algorithms/combine.vcproj
==============================================================================
--- trunk/libs/geometry/test/algorithms/combine.vcproj 2011-03-13 07:10:27 EDT (Sun, 13 Mar 2011)
+++ (empty file)
@@ -1,174 +0,0 @@
-<?xml version="1.0" encoding="Windows-1252"?>
-<VisualStudioProject
- ProjectType="Visual C++"
- Version="8.00"
- Name="combine"
- ProjectGUID="{5330DAB1-DF27-44FC-971B-3C5094F82FA3}"
- RootNamespace="combine"
- Keyword="Win32Proj"
- >
- <Platforms>
- <Platform
- Name="Win32"
- />
- </Platforms>
- <ToolFiles>
- </ToolFiles>
- <Configurations>
- <Configuration
- Name="Debug|Win32"
- OutputDirectory="$(SolutionDir)$(ConfigurationName)"
- IntermediateDirectory="$(ConfigurationName)\combine"
- ConfigurationType="1"
- InheritedPropertySheets="..\boost.vsprops;..\ttmath.vsprops"
- CharacterSet="1"
- >
- <Tool
- Name="VCPreBuildEventTool"
- />
- <Tool
- Name="VCCustomBuildTool"
- />
- <Tool
- Name="VCXMLDataGeneratorTool"
- />
- <Tool
- Name="VCWebServiceProxyGeneratorTool"
- />
- <Tool
- Name="VCMIDLTool"
- />
- <Tool
- Name="VCCLCompilerTool"
- Optimization="0"
- AdditionalIncludeDirectories="../../../..;.."
- PreprocessorDefinitions="WIN32;_DEBUG;_CONSOLE"
- ExceptionHandling="2"
- RuntimeLibrary="1"
- UsePrecompiledHeader="0"
- DebugInformationFormat="1"
- />
- <Tool
- Name="VCManagedResourceCompilerTool"
- />
- <Tool
- Name="VCResourceCompilerTool"
- />
- <Tool
- Name="VCPreLinkEventTool"
- />
- <Tool
- Name="VCLinkerTool"
- GenerateDebugInformation="true"
- SubSystem="1"
- TargetMachine="1"
- />
- <Tool
- Name="VCALinkTool"
- />
- <Tool
- Name="VCManifestTool"
- />
- <Tool
- Name="VCXDCMakeTool"
- />
- <Tool
- Name="VCBscMakeTool"
- />
- <Tool
- Name="VCFxCopTool"
- />
- <Tool
- Name="VCAppVerifierTool"
- />
- <Tool
- Name="VCWebDeploymentTool"
- />
- <Tool
- Name="VCPostBuildEventTool"
- />
- </Configuration>
- <Configuration
- Name="Release|Win32"
- OutputDirectory="$(SolutionDir)$(ConfigurationName)"
- IntermediateDirectory="$(ConfigurationName)\combine"
- ConfigurationType="1"
- InheritedPropertySheets="..\boost.vsprops;..\ttmath.vsprops"
- CharacterSet="1"
- WholeProgramOptimization="1"
- >
- <Tool
- Name="VCPreBuildEventTool"
- />
- <Tool
- Name="VCCustomBuildTool"
- />
- <Tool
- Name="VCXMLDataGeneratorTool"
- />
- <Tool
- Name="VCWebServiceProxyGeneratorTool"
- />
- <Tool
- Name="VCMIDLTool"
- />
- <Tool
- Name="VCCLCompilerTool"
- AdditionalIncludeDirectories="../../../..;.."
- PreprocessorDefinitions="WIN32;NDEBUG;_CONSOLE"
- ExceptionHandling="2"
- UsePrecompiledHeader="0"
- />
- <Tool
- Name="VCManagedResourceCompilerTool"
- />
- <Tool
- Name="VCResourceCompilerTool"
- />
- <Tool
- Name="VCPreLinkEventTool"
- />
- <Tool
- Name="VCLinkerTool"
- SubSystem="1"
- OptimizeReferences="2"
- EnableCOMDATFolding="2"
- TargetMachine="1"
- />
- <Tool
- Name="VCALinkTool"
- />
- <Tool
- Name="VCManifestTool"
- />
- <Tool
- Name="VCXDCMakeTool"
- />
- <Tool
- Name="VCBscMakeTool"
- />
- <Tool
- Name="VCFxCopTool"
- />
- <Tool
- Name="VCAppVerifierTool"
- />
- <Tool
- Name="VCWebDeploymentTool"
- />
- <Tool
- Name="VCPostBuildEventTool"
- />
- </Configuration>
- </Configurations>
- <References>
- </References>
- <Files>
- <File
- RelativePath=".\combine.cpp"
- >
- </File>
- </Files>
- <Globals>
- </Globals>
-</VisualStudioProject>

Copied: trunk/libs/geometry/test/algorithms/expand.cpp (from r69910, /trunk/libs/geometry/test/algorithms/combine.cpp)
==============================================================================
--- /trunk/libs/geometry/test/algorithms/combine.cpp (original)
+++ trunk/libs/geometry/test/algorithms/expand.cpp 2011-03-13 07:10:27 EDT (Sun, 13 Mar 2011)
@@ -6,7 +6,7 @@
 // Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at
 // http://www.boost.org/LICENSE_1_0.txt)
 
-#include <algorithms/test_combine.hpp>
+#include <algorithms/test_expand.hpp>
 
 
 #include <boost/geometry/algorithms/make.hpp>
@@ -23,21 +23,21 @@
 {
     bg::model::box<Point> b = bg::make_inverse<bg::model::box<Point> >();
 
- test_combine<Point>(b, "POINT(1 2 5)", "(1,2,5),(1,2,5)");
- test_combine<Point>(b, "POINT(3 4 6)", "(1,2,5),(3,4,6)");
+ test_expand<Point>(b, "POINT(1 2 5)", "(1,2,5),(1,2,5)");
+ test_expand<Point>(b, "POINT(3 4 6)", "(1,2,5),(3,4,6)");
 
- test_combine<Point>(b, "POINT(4 4 5)", "(1,2,5),(4,4,6)");
- test_combine<Point>(b, "POINT(4 5 5)", "(1,2,5),(4,5,6)");
- test_combine<Point>(b, "POINT(10 10 4)", "(1,2,4),(10,10,6)");
- test_combine<Point>(b, "POINT(9 9 4)", "(1,2,4),(10,10,6)");
-
- test_combine<Point>(b, "POINT(0 2 7)", "(0,2,4),(10,10,7)");
- test_combine<Point>(b, "POINT(0 0 7)", "(0,0,4),(10,10,7)");
- test_combine<Point>(b, "POINT(-1 -1 5)", "(-1,-1,4),(10,10,7)");
- test_combine<Point>(b, "POINT(0 0 5)", "(-1,-1,4),(10,10,7)");
+ test_expand<Point>(b, "POINT(4 4 5)", "(1,2,5),(4,4,6)");
+ test_expand<Point>(b, "POINT(4 5 5)", "(1,2,5),(4,5,6)");
+ test_expand<Point>(b, "POINT(10 10 4)", "(1,2,4),(10,10,6)");
+ test_expand<Point>(b, "POINT(9 9 4)", "(1,2,4),(10,10,6)");
+
+ test_expand<Point>(b, "POINT(0 2 7)", "(0,2,4),(10,10,7)");
+ test_expand<Point>(b, "POINT(0 0 7)", "(0,0,4),(10,10,7)");
+ test_expand<Point>(b, "POINT(-1 -1 5)", "(-1,-1,4),(10,10,7)");
+ test_expand<Point>(b, "POINT(0 0 5)", "(-1,-1,4),(10,10,7)");
 
- test_combine<Point>(b, "POINT(15 -1 0)", "(-1,-1,0),(15,10,7)");
- test_combine<Point>(b, "POINT(-1 15 10)", "(-1,-1,0),(15,15,10)");
+ test_expand<Point>(b, "POINT(15 -1 0)", "(-1,-1,0),(15,10,7)");
+ test_expand<Point>(b, "POINT(-1 15 10)", "(-1,-1,0),(15,15,10)");
 }
 
 template <typename Point>
@@ -46,15 +46,15 @@
     typedef bg::model::box<Point> box_type;
     box_type b = bg::make_inverse<box_type>();
 
- test_combine<box_type>(b, "BOX(0 2 5,4 4 6)", "(0,2,5),(4,4,6)");
- test_combine<box_type>(b, "BOX(0 1 5,4 6 6)", "(0,1,5),(4,6,6)");
- test_combine<box_type>(b, "BOX(-1 -1 6,10 10 5)", "(-1,-1,5),(10,10,6)");
- test_combine<box_type>(b, "BOX(3 3 6,3 3 5)", "(-1,-1,5),(10,10,6)");
-
- test_combine<box_type>(b, "BOX(3 15 7,-1 3 4)", "(-1,-1,4),(10,15,7)");
- test_combine<box_type>(b, "BOX(-15 3 7,3 20 4)", "(-15,-1,4),(10,20,7)");
- test_combine<box_type>(b, "BOX(3 -20 8,3 20 3)", "(-15,-20,3),(10,20,8)");
- test_combine<box_type>(b, "BOX(-20 3 8,20 3 3)", "(-20,-20,3),(20,20,8)");
+ test_expand<box_type>(b, "BOX(0 2 5,4 4 6)", "(0,2,5),(4,4,6)");
+ test_expand<box_type>(b, "BOX(0 1 5,4 6 6)", "(0,1,5),(4,6,6)");
+ test_expand<box_type>(b, "BOX(-1 -1 6,10 10 5)", "(-1,-1,5),(10,10,6)");
+ test_expand<box_type>(b, "BOX(3 3 6,3 3 5)", "(-1,-1,5),(10,10,6)");
+
+ test_expand<box_type>(b, "BOX(3 15 7,-1 3 4)", "(-1,-1,4),(10,15,7)");
+ test_expand<box_type>(b, "BOX(-15 3 7,3 20 4)", "(-15,-1,4),(10,20,7)");
+ test_expand<box_type>(b, "BOX(3 -20 8,3 20 3)", "(-15,-20,3),(10,20,8)");
+ test_expand<box_type>(b, "BOX(-20 3 8,20 3 3)", "(-20,-20,3),(20,20,8)");
 }
 
 
@@ -74,13 +74,13 @@
 
     box_type b = bg::make_inverse<box_type>();
 
- test_combine<box_type>(b, "BOX(1 1,2 2)", "(1,1),(2,2)");
+ test_expand<box_type>(b, "BOX(1 1,2 2)", "(1,1),(2,2)");
 
     // Test an 'incorrect' box -> should also correctly update the bbox
- test_combine<box_type>(b, "BOX(3 4,0 1)", "(0,1),(3,4)");
+ test_expand<box_type>(b, "BOX(3 4,0 1)", "(0,1),(3,4)");
 
     // Test a segment
- test_combine<segment_type>(b, "SEGMENT(5 6,7 8)", "(0,1),(7,8)");
+ test_expand<segment_type>(b, "SEGMENT(5 6,7 8)", "(0,1),(7,8)");
 }
 
 template <typename Point>
@@ -88,16 +88,16 @@
 {
     bg::model::box<Point> b = bg::make_inverse<bg::model::box<Point> >();
 
- test_combine<Point>(b, "POINT(179.73 71.56)",
+ test_expand<Point>(b, "POINT(179.73 71.56)",
             "(179.73,71.56),(179.73,71.56)");
- test_combine<Point>(b, "POINT(177.47 71.23)",
+ test_expand<Point>(b, "POINT(177.47 71.23)",
             "(177.47,71.23),(179.73,71.56)");
 
     // It detects that this point is lying RIGHT of the others,
- // and then it "combines" it.
+ // and then it "expands" it.
     // It might be argued that "181.22" is displayed instead. However, they are
     // the same.
- test_combine<Point>(b, "POINT(-178.78 70.78)",
+ test_expand<Point>(b, "POINT(-178.78 70.78)",
             "(177.47,70.78),(-178.78,71.56)");
 }
 
@@ -107,16 +107,16 @@
 {
     bg::model::box<Point> b = bg::make_inverse<bg::model::box<Point> >();
 
- test_combine<Point>(b, "POINT(3.128 1.249)",
+ test_expand<Point>(b, "POINT(3.128 1.249)",
             "(3.128,1.249),(3.128,1.249)");
- test_combine<Point>(b, "POINT(3.097 1.243)",
+ test_expand<Point>(b, "POINT(3.097 1.243)",
             "(3.097,1.243),(3.128,1.249)");
 
     // It detects that this point is lying RIGHT of the others,
- // and then it "combines" it.
+ // and then it "expands" it.
     // It might be argued that "181.22" is displayed instead. However, they are
     // the same.
- test_combine<Point>(b, "POINT(-3.121 1.235)",
+ test_expand<Point>(b, "POINT(-3.121 1.235)",
             "(3.097,1.235),(-3.121,1.249)");
 }
 

Copied: trunk/libs/geometry/test/algorithms/expand.vcproj (from r69910, /trunk/libs/geometry/test/algorithms/combine.vcproj)
==============================================================================
--- /trunk/libs/geometry/test/algorithms/combine.vcproj (original)
+++ trunk/libs/geometry/test/algorithms/expand.vcproj 2011-03-13 07:10:27 EDT (Sun, 13 Mar 2011)
@@ -2,9 +2,9 @@
 <VisualStudioProject
         ProjectType="Visual C++"
         Version="8.00"
- Name="combine"
+ Name="expand"
         ProjectGUID="{5330DAB1-DF27-44FC-971B-3C5094F82FA3}"
- RootNamespace="combine"
+ RootNamespace="expand"
         Keyword="Win32Proj"
>
         <Platforms>
@@ -18,7 +18,7 @@
                 <Configuration
                         Name="Debug|Win32"
                         OutputDirectory="$(SolutionDir)$(ConfigurationName)"
- IntermediateDirectory="$(ConfigurationName)\combine"
+ IntermediateDirectory="$(ConfigurationName)\expand"
                         ConfigurationType="1"
                         InheritedPropertySheets="..\boost.vsprops;..\ttmath.vsprops"
                         CharacterSet="1"
@@ -91,7 +91,7 @@
                 <Configuration
                         Name="Release|Win32"
                         OutputDirectory="$(SolutionDir)$(ConfigurationName)"
- IntermediateDirectory="$(ConfigurationName)\combine"
+ IntermediateDirectory="$(ConfigurationName)\expand"
                         ConfigurationType="1"
                         InheritedPropertySheets="..\boost.vsprops;..\ttmath.vsprops"
                         CharacterSet="1"
@@ -165,7 +165,7 @@
         </References>
         <Files>
                 <File
- RelativePath=".\combine.cpp"
+ RelativePath=".\expand.cpp"
>
                 </File>
         </Files>

Deleted: trunk/libs/geometry/test/algorithms/test_combine.hpp
==============================================================================
--- trunk/libs/geometry/test/algorithms/test_combine.hpp 2011-03-13 07:10:27 EDT (Sun, 13 Mar 2011)
+++ (empty file)
@@ -1,55 +0,0 @@
-// Boost.Geometry (aka GGL, Generic Geometry Library) test file
-//
-// Copyright Barend Gehrels 2007-2009, Geodan, Amsterdam, the Netherlands
-// Use, modification and distribution is subject to the Boost Software License,
-// Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at
-// http://www.boost.org/LICENSE_1_0.txt)
-
-#ifndef BOOST_GEOMETRY_TEST_COMBINE_HPP
-#define BOOST_GEOMETRY_TEST_COMBINE_HPP
-
-
-#include <geometry_test_common.hpp>
-
-#include <boost/geometry/algorithms/combine.hpp>
-#include <boost/geometry/strategies/strategies.hpp>
-#include <boost/geometry/domains/gis/io/wkt/read_wkt.hpp>
-#include <boost/geometry/algorithms/assign.hpp>
-#include <boost/geometry/util/write_dsv.hpp>
-
-
-template <typename Geometry, typename Box>
-void test_combine(Box& box,
- std::string const& wkt,
- std::string const& expected)
-{
- Geometry geometry;
- bg::read_wkt(wkt, geometry);
-
- bg::combine(box, geometry);
-
- std::ostringstream out;
- out << bg::dsv(box, ",", "(", ")", ",", "", "");
-
- BOOST_CHECK_EQUAL(out.str(), expected);
-}
-
-template <typename Geometry, typename Box>
-void test_combine_other_strategy(Box& box,
- std::string const& wkt,
- std::string const& expected)
-{
- Geometry geometry;
- bg::read_wkt(wkt, geometry);
-
-
- bg::combine(box, geometry);
-
- std::ostringstream out;
- out << bg::dsv(box, ",", "(", ")", ",", "", "");
-
- BOOST_CHECK_EQUAL(out.str(), expected);
-}
-
-
-#endif

Copied: trunk/libs/geometry/test/algorithms/test_expand.hpp (from r69910, /trunk/libs/geometry/test/algorithms/test_combine.hpp)
==============================================================================
--- /trunk/libs/geometry/test/algorithms/test_combine.hpp (original)
+++ trunk/libs/geometry/test/algorithms/test_expand.hpp 2011-03-13 07:10:27 EDT (Sun, 13 Mar 2011)
@@ -5,13 +5,13 @@
 // Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at
 // http://www.boost.org/LICENSE_1_0.txt)
 
-#ifndef BOOST_GEOMETRY_TEST_COMBINE_HPP
-#define BOOST_GEOMETRY_TEST_COMBINE_HPP
+#ifndef BOOST_GEOMETRY_TEST_EXPAND_HPP
+#define BOOST_GEOMETRY_TEST_EXPAND_HPP
 
 
 #include <geometry_test_common.hpp>
 
-#include <boost/geometry/algorithms/combine.hpp>
+#include <boost/geometry/algorithms/expand.hpp>
 #include <boost/geometry/strategies/strategies.hpp>
 #include <boost/geometry/domains/gis/io/wkt/read_wkt.hpp>
 #include <boost/geometry/algorithms/assign.hpp>
@@ -19,14 +19,14 @@
 
 
 template <typename Geometry, typename Box>
-void test_combine(Box& box,
+void test_expand(Box& box,
                   std::string const& wkt,
                   std::string const& expected)
 {
     Geometry geometry;
     bg::read_wkt(wkt, geometry);
 
- bg::combine(box, geometry);
+ bg::expand(box, geometry);
 
     std::ostringstream out;
     out << bg::dsv(box, ",", "(", ")", ",", "", "");
@@ -35,7 +35,7 @@
 }
 
 template <typename Geometry, typename Box>
-void test_combine_other_strategy(Box& box,
+void test_expand_other_strategy(Box& box,
                   std::string const& wkt,
                   std::string const& expected)
 {
@@ -43,7 +43,7 @@
     bg::read_wkt(wkt, geometry);
 
 
- bg::combine(box, geometry);
+ bg::expand(box, geometry);
 
     std::ostringstream out;
     out << bg::dsv(box, ",", "(", ")", ",", "", "");


Boost-Commit list run by bdawes at acm.org, david.abrahams at rcn.com, gregod at cs.rpi.edu, cpdaniel at pacbell.net, john at johnmaddock.co.uk
--- trunk/libs/geometry/doc/src/examples/algorithms/assign_inverse.cpp (original)
+++ trunk/libs/geometry/doc/src/examples/algorithms/assign_inverse.cpp 2011-03-13 07:10:27 EDT (Sun, 13 Mar 2011)
@@ -8,7 +8,7 @@
 // Quickbook Example
 
 //[assign_inverse
//` Usage of assign_inverse and combine to conveniently determine bounding 3D box of two points
 
 #include <iostream>
 
@@ -25,8 +25,8 @@
     box all;
     assign_inverse(all);
     std::cout << dsv(all) << std::endl;
- combine(all, point(0, 0, 0));
- combine(all, point(1, 2, 3));
+ expand(all, point(0, 0, 0));
+ expand(all, point(1, 2, 3));
     std::cout << dsv(all) << std::endl;
 
     return 0;
@@ -8,7 +8,7 @@
 
 //[assign_inverse
-//` Usage of assign_inverse and combine to conveniently determine bounding 3D box of two points
+//` Usage of assign_inverse and expand to conveniently determine bounding 3D box of two points
 
 #include <iostream>

Modified: trunk/libs/geometry/doc/src/examples/algorithms/make_inverse.cpp
==============================================================================
--- trunk/libs/geometry/doc/src/examples/algorithms/make_inverse.cpp (original)
+++ trunk/libs/geometry/doc/src/examples/algorithms/make_inverse.cpp 2011-03-13 07:10:27 EDT (Sun, 13 Mar 2011)
@@ -8,7 +8,7 @@
 // Quickbook Example
 
 //[make_inverse
//` Usage of make_inverse and combine to conveniently determine bounding box of several objects
 
 #include <iostream>
 
@@ -25,8 +25,8 @@
 
     box all = make_inverse<box>();
     std::cout << dsv(all) << std::endl;
- combine(all, make<box>(0, 0, 3, 4));
- combine(all, make<box>(2, 2, 5, 6));
+ expand(all, make<box>(0, 0, 3, 4));
+ expand(all, make<box>(2, 2, 5, 6));
     std::cout << dsv(all) << std::endl;
 
     return 0;
@@ -8,7 +8,7 @@
 
 //[make_inverse
-//` Usage of make_inverse and combine to conveniently determine bounding box of several objects
+//` Usage of make_inverse and expand to conveniently determine bounding box of several objects
 
 #include <iostream>

Modified: trunk/libs/geometry/example/07_a_graph_route_example.cpp
==============================================================================